# Intake Dynamodb

[![Available on pypi](https://img.shields.io/pypi/v/intake-dynamodb.svg)](https://pypi.python.org/pypi/intake-dynamodb/)

intake-dynamodb is a [plugin](https://intake.readthedocs.io/en/latest/plugin-directory.html) for Intake
for reading data from dynamodb

### Acknowledgements

Developed in the [Met Office Informatics Lab](https://www.metoffice.gov.uk/research/foundation/informatics-lab/index).
